All of lore.kernel.org
 help / color / mirror / Atom feed
From: Oscar Mateo <oscar.mateo@intel.com>
To: intel-gfx@lists.freedesktop.org
Subject: [PATCH 04/22] drm/i915/icl: WaL3BankAddressHashing
Date: Fri,  6 Apr 2018 15:25:00 -0700	[thread overview]
Message-ID: <1523053518-20827-4-git-send-email-oscar.mateo@intel.com> (raw)
In-Reply-To: <1523053518-20827-1-git-send-email-oscar.mateo@intel.com>

Revert to an L3 non-hash model, for performance reasons.

v2:
  - Place the WA name above the actual change
  - Improve the register naming
v3:
  - Rebased
  - Renamed to Wa_1604223664

Cc: Mika Kuoppala <mika.kuoppala@linux.intel.com>
Signed-off-by: Oscar Mateo <oscar.mateo@intel.com>
---
 drivers/gpu/drm/i915/i915_reg.h |  6 ++++++
 drivers/gpu/drm/i915/intel_pm.c | 20 ++++++++++++++++----
 2 files changed, 22 insertions(+), 4 deletions(-)

diff --git a/drivers/gpu/drm/i915/i915_reg.h b/drivers/gpu/drm/i915/i915_reg.h
index 78abb49..10ed35f 100644
--- a/drivers/gpu/drm/i915/i915_reg.h
+++ b/drivers/gpu/drm/i915/i915_reg.h
@@ -8199,6 +8199,12 @@ enum {
 #define GEN8_GARBCNTL				_MMIO(0xB004)
 #define   GEN9_GAPS_TSV_CREDIT_DISABLE		(1 << 7)
 #define   GEN11_ARBITRATION_PRIO_ORDER_MASK	(0x3f << 22)
+#define   GEN11_HASH_CTRL_EXCL_MASK		(0x7f << 0)
+#define   GEN11_HASH_CTRL_EXCL_BIT0		(1 << 0)
+
+#define GEN11_GLBLINVL				_MMIO(0xB404)
+#define   GEN11_BANK_HASH_ADDR_EXCL_BIT0	(1 << 0)
+#define   GEN11_BANK_HASH_ADDR_EXCL_MASK	(0x3f << 5)
 
 #define GEN11_GACB_PERF_CTRL			_MMIO(0x4B80)
 #define   GEN11_HASH_CTRL_MASK			(0x3 << 12 | 0xf << 0)
diff --git a/drivers/gpu/drm/i915/intel_pm.c b/drivers/gpu/drm/i915/intel_pm.c
index 03c5de3..58974fa 100644
--- a/drivers/gpu/drm/i915/intel_pm.c
+++ b/drivers/gpu/drm/i915/intel_pm.c
@@ -8513,11 +8513,23 @@ static void icl_init_clock_gating(struct drm_i915_private *dev_priv)
 	I915_WRITE(GEN8_L3SQCREG4, (I915_READ(GEN8_L3SQCREG4) |
 				    GEN8_LQSC_FLUSH_COHERENT_LINES));
 
-	/* Wa_1405543622:icl
-	 * Formerly known as WaGAPZPriorityScheme
+	I915_WRITE(GEN8_GARBCNTL,
+		   /* Wa_1604223664:icl
+		    * Formerly known as WaL3BankAddressHashing
+		    */
+		   ((I915_READ(GEN8_GARBCNTL) & ~GEN11_HASH_CTRL_EXCL_MASK) |
+		    GEN11_HASH_CTRL_EXCL_BIT0 |
+		    /* Wa_1405543622:icl
+		     * Formerly known as WaGAPZPriorityScheme
+		     */
+		    GEN11_ARBITRATION_PRIO_ORDER_MASK));
+
+	/* Wa_1604223664:icl
+	 * Formerly known as WaL3BankAddressHashing
 	 */
-	I915_WRITE(GEN8_GARBCNTL, (I915_READ(GEN8_GARBCNTL) |
-				   GEN11_ARBITRATION_PRIO_ORDER_MASK));
+	I915_WRITE(GEN11_GLBLINVL,
+		   ((I915_READ(GEN11_GLBLINVL) & ~GEN11_BANK_HASH_ADDR_EXCL_MASK) |
+		    GEN11_BANK_HASH_ADDR_EXCL_BIT0));
 
 	/* WaModifyGamTlbPartitioning:icl */
 	I915_WRITE(GEN11_GACB_PERF_CTRL,
-- 
1.9.1

_______________________________________________
Intel-gfx mailing list
Intel-gfx@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/intel-gfx

  parent reply	other threads:[~2018-04-06 22:25 UTC|newest]

Thread overview: 34+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2018-04-06 22:24 [PATCH 01/22] drm/i915/icl: Introduce initial Icelake Workarounds Oscar Mateo
2018-04-06 22:24 ` [PATCH 02/22] drm/i915/icl: WaGAPZPriorityScheme Oscar Mateo
2018-04-06 22:24 ` [PATCH 03/22] drm/i915/icl: WaModifyGamTlbPartitioning Oscar Mateo
2018-04-06 22:25 ` Oscar Mateo [this message]
2018-04-06 22:25 ` [PATCH 05/22] drm/i915/icl: WaDisableCleanEvicts Oscar Mateo
2018-04-06 22:25 ` [PATCH 06/22] drm/i915/icl: WaDisableImprovedTdlClkGating Oscar Mateo
2018-04-06 22:25 ` [PATCH 07/22] drm/i915/icl: WaCL2SFHalfMaxAlloc Oscar Mateo
2018-04-06 22:25 ` [PATCH 08/22] drm/i915/icl: WaDisCtxReload Oscar Mateo
2018-04-06 22:25 ` [PATCH 09/22] drm/i915/icl: WaSendPushConstantsFromMMIO Oscar Mateo
2018-04-06 22:25 ` [PATCH 10/22] drm/i915/icl: WaAllowUMDToModifyHalfSliceChicken2 Oscar Mateo
2018-04-06 22:25 ` [PATCH 11/22] drm/i915/icl: WaAllowUMDToModifyHalfSliceChicken7 Oscar Mateo
2018-04-06 22:25 ` [PATCH 12/22] drm/i915/icl: WaAllowUmdWriteTRTTRootTable Oscar Mateo
2018-04-06 22:25 ` [PATCH 13/22] drm/i915/icl: WaAllowUMDToModifySamplerMode Oscar Mateo
2018-04-06 22:25 ` [PATCH 14/22] drm/i915/icl: WaEnableStateCacheRedirectToCS Oscar Mateo
2018-04-06 22:25 ` [PATCH 15/22] drm/i915/icl: Enable Sampler DFR Oscar Mateo
2018-04-06 22:25 ` [PATCH 16/22] drm/i915/icl: Wa_1405779004 Oscar Mateo
2018-04-06 22:25 ` [PATCH 17/22] drm/i915/icl: Wa_1406680159 and Wa_2201832410 Oscar Mateo
2018-04-06 22:25 ` [PATCH 18/22] drm/i915/icl: Wa_1604302699 Oscar Mateo
2018-04-06 22:25 ` [PATCH 19/22] drm/i915/icl: Wa_2006665173 Oscar Mateo
2018-04-06 22:25 ` [PATCH 20/22] drm/i915/icl: Wa_1406838659 Oscar Mateo
2018-04-06 22:25 ` [PATCH 21/22] drm/i915/icl: WaForwardProgressSoftReset Oscar Mateo
2018-04-06 22:25 ` [PATCH 22/22] drm/i915/icl: WaEnableFloatBlendOptimization Oscar Mateo
2018-04-06 22:43 ` ✗ Fi.CI.CHECKPATCH: warning for series starting with [01/22] drm/i915/icl: Introduce initial Icelake Workarounds Patchwork
2018-04-06 22:58 ` ✓ Fi.CI.BAT: success " Patchwork
2018-04-07  4:34 ` ✗ Fi.CI.IGT: failure " Patchwork
2018-04-09 19:53 ` [PATCH 01/22] " Chris Wilson
2018-04-09 21:33   ` Oscar Mateo
2018-04-13 16:00 Oscar Mateo
2018-04-13 16:00 ` [PATCH 04/22] drm/i915/icl: WaL3BankAddressHashing Oscar Mateo
2018-04-20 20:33 [PATCH v4 00/22] Workarounds for Icelake Oscar Mateo
2018-04-20 20:33 ` [PATCH 04/22] drm/i915/icl: WaL3BankAddressHashing Oscar Mateo
2018-05-02 10:23   ` Mika Kuoppala
2018-05-02 19:46     ` Oscar Mateo Lozano
2018-05-02 20:33 [PATCH v2 00/22] Workarounds for Icelake Oscar Mateo
2018-05-02 20:34 ` [PATCH 04/22] drm/i915/icl: WaL3BankAddressHashing Oscar Mateo
2018-05-04 10:22   ` Mika Kuoppala
2018-05-08 21:29 [PATCH v3 00/22] Workarounds for Icelake Oscar Mateo
2018-05-08 21:29 ` [PATCH 04/22] drm/i915/icl: WaL3BankAddressHashing Oscar Mateo

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1523053518-20827-4-git-send-email-oscar.mateo@intel.com \
    --to=oscar.mateo@intel.com \
    --cc=intel-gfx@lists.freedesktop.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.